# -*- coding: utf-8 -*-
from django.conf.urls import url
from django.contrib import admin

from .views import TicketList, TicketCreate, TicketDelete, TicketUpdate

from simpletickets.settings.ticketSettings import (ST_REST_API,
    API_BASE_URL
    )  # noqa

from .api.views import (UserTicketListCreate, UserTicketUpdateDelete,
    StaffTicketList, StaffTicketUpdate
    )

admin.autodiscover()

urlpatterns = [
    url(r'^list/$', TicketList.as_view(), name='ticketList'),
    url(r'^new-ticket/$', TicketCreate.as_view(), name='newTicket'),
    url(r'^edit-ticket-(?P<ST_id>[\d]*)/$',
        TicketUpdate.as_view(), name='TicketUpdate'
        ),
    url(r'^delete-ticket-(?P<ST_id>[\d]*)/$',
        TicketDelete.as_view(), name='TicketDelete'
        ),
    ]

if ST_REST_API:
    urlpatterns += [
        url(r'^{url}/list-create/$'.format(url=API_BASE_URL),
            UserTicketListCreate.as_view(),
            name='apiListCreate'
            ),
        url(r'^{url}/ticket-(?P<pk>[\d]+)-update-destroy/$'.format(
                url=API_BASE_URL
                ),
            UserTicketUpdateDelete.as_view(),
            name='updateDestroyCreate'
            ),
        url(r'^{url}/staff-list/$'.format(url=API_BASE_URL),
            StaffTicketList.as_view(),
            name='apiListCreate'
            ),
        url(r'^{url}/staff-ticket-(?P<pk>[\d]+)-update/$'.format(
                url=API_BASE_URL
                ),
            StaffTicketUpdate.as_view(),
            name='updateDestroyCreate'
            ),
        ]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
from email.mime.image import MIMEImage  # noqa

from django.template.loader import render_to_string
from django.core.mail import EmailMultiAlternatives

from django.conf import settings


class EmailManager(EmailMultiAlternatives):
    def __init__(self, context, subject='', body='',
            from_email=settings.EMAIL_HOST_USER, to=None, bcc=None,
            connection=None, attachments=None, headers=None, alternatives=None,
            cc=None, reply_to=None):

        txt_content = render_to_string(body, context)

        self.reply_to = reply_to or settings.EMAIL_HOST_USER
        super(EmailMultiAlternatives, self).__init__(
            subject, txt_content, from_email, to, bcc, connection,
            attachments, headers, cc, reply_to)
        self.alternatives = alternatives or []
        self.context = context
        # self.attachImages(['image1.png', 'image2.png'])

    def attachImages(self, imagenames):
        for image in imagenames:
            fp = open(os.path.join(settings.MEDIA_ROOT,
                    image), 'rb')
            msg_img = MIMEImage(fp.read())
            fp.close()
            msg_img.add_header('Content-ID', '<{}>'.format(image))
            self.attach(msg_img)

    def attachHtml(self, template, context):
        html_content = render_to_string(template, context)
        self.attach_alternative(html_content, "text/html")
        self.mixed_subtype = 'related'



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('simpletickets', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ticket',
            name='state',
            field=models.CharField(default=b'new', max_length=15, choices=[(b'new', 'new'), (b'assigned', 'assigned'), (b'solved', 'solved'), (b'closed', 'closed')]),
        ),
    ]



# -*- coding: utf-8 -*-
import os

from django.db import models
from django.contrib.auth.models import User
from django.utils import timezone
from django.utils.safestring import mark_safe
from django.utils.translation import ugettext as _
from django.utils.translation import ugettext_lazy as ugl
from django.conf import settings

from .settings import (ST_ATTACHMENTS, ST_DELTA_CLOSE,
    ST_TCKT_TYPE, ST_TCKT_SEVERITY, ST_TCKT_STATE,
    )
from .helpers import monitor, monitorfile, monitorfile_url

from .simpleemail.email_helper import EmailManager


def uploadAttachment(instance, filename):
    return os.path.join(ST_ATTACHMENTS, filename)


class TicketManager(models.Manager):
    def n_solved(self, user):
        return len(Ticket.objects.filter(state__gt=7, user=user))

    def n_total(self, user):
        return len(Ticket.objects.filter(user=user))

    def all(self):
        all_objects = super(TicketManager, self).all()

        # rewrite the all() method
        # so we can update files older than ST_DELTA_CLOSE to state 9
        now_minus_delta = timezone.now() - ST_DELTA_CLOSE
        state_8_delta = all_objects.filter(
            state=8,
            resolution_date__lt=now_minus_delta
            )
        state_8_delta.update(state=9)

        return all_objects


class Ticket(models.Model):
    objects = TicketManager()
    ticket_number = models.CharField(max_length=8, blank=True, null=True)

    user = models.ForeignKey(User,)
    staff = models.ForeignKey(User,
        limit_choices_to={'is_staff': True},
        related_name='usrStaff',
        blank=True, null=True,
        )

    ticket_type = models.IntegerField(default=2, choices=ST_TCKT_TYPE)
    severity = models.IntegerField(default=3, choices=ST_TCKT_SEVERITY)
    state = models.IntegerField(default=1, choices=ST_TCKT_STATE)

    description = models.TextField(ugl(u'Description'), default='...')
    attachment = models.FileField(upload_to=uploadAttachment,
        blank=True, null=True)

    resolution_text = models.TextField(ugl(u'Resolution text'), default='')

    creation_date = models.DateTimeField(_('Creation Date'),
        default=timezone.now)
    modification_date = models.DateTimeField(_('Last Modification Date'),
        blank=True, null=True)
    resolution_date = models.DateTimeField(_('Resolution date'),
        blank=True, null=True)

    resolution_delta = models.FloatField(_('delayed time in seconds'),
        blank=True, null=True)

    def mntrfile(self):
        return monitorfile_url(self)

    def resolucion_tag(self):
        return mark_safe(self.resolution_text)

    def humanized_delta(self):
        return self.resolution_date - self.creation_date

    def save(self, *args, **kwargs):
        self.modification_date = timezone.now()
        if self.id:
            header_msg = self.changesChecker(
                Ticket.objects.get(id=self.id),
                self
                )
        else:
            header_msg = _('{date} #### Ticket created ####\n').format(
                date=self.creation_date,
                )
        if self.state == 1:
            if self.staff:
                self.state = 2
        elif self.state > 7:
            self.resolution_date = timezone.now()
        if self.resolution_date:
            delta = self.resolution_date - self.creation_date
            self.resolution_delta = int(delta.total_seconds())
        super(Ticket, self).save(*args, **kwargs)
        monitor(monitorfile(self), header_msg)
        if not self.ticket_number:
            self.ticket_number = str(self.creation_date)[2:4] + (
                '00000{id}'.format(id=self.id)
                )[-6:]
            self.save()

    def _mailSender(self):
        context = ''
        if self.state == 9:
            context = {}
            subject = _(
                'Your ticket number {ticket_number} has been solved'
                ).format(ticket_number=self.ticket_number)
            body = _('We are glad we have solved your ticket number: '
                '{ticket_number}\n\n'
                'The resolution time was {resolution_delta}.\n\n'
                'You have {ST_DELTA_CLOSE} hours to reopen it, '
                'remember to carefully explain your reasons.\nThe Team'
                ).format(ticket_number=self.ticket_number,
                    resolution_delta=self.resolution_delta,
                    ST_DELTA_CLOSE=ST_DELTA_CLOSE
                    )
            email = self.user.email
            self.sendEmail(context, subject, body, email)
        if self.state == 2:
            context = {}
            subject = _(
                'Ticket {ticket_number} assigned.\n\nThe Team'
                ).format(ticket_number=self.ticket_number)
            body = _(
                'You have been assigned ticket number {ticket_number}.'
                '\n\nThe Team'
                ).format(ticket_number=self.ticket_number)
            email = self.staff.email
            self.sendEmail(context, subject, body, email)

    def changesChecker(self, original, actual):
        MONITORIZED = ['ticket_number', 'user', 'staff', 'ticket_type',
            'severity', 'state', 'description', 'resolution_text'
            ]
        msg = []
        for attribute in MONITORIZED:
            attr_ori = getattr(original, attribute)
            attr_act = getattr(actual, attribute)
            value = attr_act
            if attribute in ['ticket_type', 'severity', 'state']:
                value = getattr(actual, 'get_{attribute}_display'.format(
                    attribute=attribute)
                    )()
            if not attr_ori == attr_act and (attr_ori or attr_act):
                msg.append(
                    '[{attrname}: {attrvalue}]'.format(
                        attrname=attribute.upper(),
                        attrvalue=value,
                        )
                    )
        if msg:
            msg = ' | '.join(msg) + '\n'
        else:
            msg = 'No changes!\n'
        return msg

    def sendEmail(self, context, subject, body, email):
        EmailManager(context,
            subject=subject,
            body=body,
            from_email=settings.EMAIL_HOST_USER,
            to=self.user.email,
            bcc=email,
            connection=None,
            attachments=None,
            headers=None,
            alternatives=None,
            cc=None,
            reply_to=None
            )

    def __unicode__(self):
        return u'{ticket_number} {user}'.format(
            ticket_number=self.ticket_number,
            user=self.user,
            )

    class Meta(object):
        verbose_name = _('Ticket')
        verbose_name_plural = _('Tickets')
        ordering = ('state', 'severity', 'creation_date')



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('simpletickets', '0002_auto_20150830_2241'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ticket',
            name='state',
            field=models.IntegerField(default=1, choices=[(1, 'new'), (2, 'assigned'), (5, 'delayed'), (8, 'solved'), (9, 'closed')]),
        ),
    ]



# -*- coding: utf-8 -*-
from rest_framework import serializers

from simpletickets.models import Ticket  # noqa


class UserTicketSerializer(serializers.ModelSerializer):
    class Meta:
        model = Ticket
        fields = ('ticket_type', 'severity', 'description')


class StaffTicketSerializer(serializers.ModelSerializer):
    class Meta:
        model = Ticket
        fields = ('staff', 'ticket_type', 'severity', 'state',
            'resolution_text',
            )



# -*- coding: utf-8 -*-
from rest_framework.permissions import BasePermission


class UserTicketPermission(BasePermission):
    def has_object_permission(self, request, view, obj):
        return request.user == obj.user


class StaffTicketPermission(BasePermission):
    def has_permission(self, request, view):
        return request.user.is_staff



# -*- coding: utf-8 -*-
from django import forms
from django.utils.translation import ugettext as _

from .models import Ticket
from .settings import ST_TCKT_STATE


class TicketFormUser(forms.ModelForm):
    class Meta(object):
        model = Ticket
        fields = ('ticket_type', 'severity', 'description')

    def clean_description(self):
        text = self.cleaned_data['description']

        if text == '...':
            raise forms.ValidationError(
                    _(u'Please explain the problem'))
        if len(text.split(' ')) < 5:
            raise forms.ValidationError(
                    _(u'Please expose your problem rigorously'))
        return text


class TicketFormStaff(forms.ModelForm):
    class Meta(object):
        model = Ticket
        fields = ('staff', 'ticket_type', 'severity', 'state',
            'resolution_text',
            )

    def clean_resolution_text(self):
        text = self.cleaned_data['resolution_text']

        if len(text.split(' ')) < 5:
            raise forms.ValidationError(
                    _(u'Please be extensive on the explanation'))
        return text

    def __init__(self, *args, **kwargs):
        super(TicketFormStaff, self).__init__(*args, **kwargs)
        CHOICES = list(ST_TCKT_STATE)[1:-1]
        self.fields['state'].choices = CHOICES



# -*- coding: utf-8 -*-
import os

from .settings import ST_ATTACHMENTS, ST_ATTACH_URL, MONITOR_FILES_DIR


def monitorfile_url(ticket):
    return ST_ATTACH_URL + '{id}-{user}.mon'.format(
        id=ticket.id, user=ticket.user
        )


def monitorfile(ticket):
    return os.path.join(
        ST_ATTACHMENTS,
        MONITOR_FILES_DIR,
        '{id}-{user}.mon'.format(
            id=ticket.id,
            user=ticket.user,
            )
        )


def monitor(myfilename, msg):
    with open(myfilename, 'a') as monitor:
        monitor.write(msg)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.utils.timezone
import simpletickets.models
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Ticket',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('ticket_number', models.CharField(max_length=8, null=True, blank=True)),
                ('ticket_type', models.IntegerField(default=2, choices=[(1, 'Inform about an error'), (2, 'Problem'), (3, 'Propose a sugestion'), (4, 'Others')])),
                ('severity', models.IntegerField(default=3, choices=[(1, 'Critical'), (2, 'Very important'), (3, 'Important'), (4, 'Normal')])),
                ('state', models.IntegerField(default=1, choices=[(1, 'new'), (2, 'assigned'), (3, 'solved'), (4, 'closed')])),
                ('description', models.TextField(default=b'...', verbose_name='Description')),
                ('attachment', models.FileField(null=True, upload_to=simpletickets.models.uploadAttachment, blank=True)),
                ('resolution_text', models.TextField(default=b'', verbose_name='Resolution text')),
                ('creation_date', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Creation Date')),
                ('modification_date', models.DateTimeField(null=True, verbose_name='Last Modification Date', blank=True)),
                ('resolution_date', models.DateTimeField(null=True, verbose_name='Resolution date', blank=True)),
                ('resolution_delta', models.FloatField(null=True, verbose_name='delayed time in seconds', blank=True)),
                ('staff', models.ForeignKey(related_name='usrStaff', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('user', models.ForeignKey(to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ('state', 'severity', 'creation_date'),
                'verbose_name': 'Ticket',
                'verbose_name_plural': 'Tickets',
            },
        ),
    ]



# -*- coding: utf-8 -*-
from django.contrib import admin

from .models import Ticket  # noqa


@admin.register(Ticket)
class TicketAdmin(admin.ModelAdmin):
    list_display = (
        'ticket_number',
        'user',
        'staff',
        'state',
        'severity',
        'ticket_type',
        'creation_date',
        )
    list_filter = (
        'user',
        'staff',
        'severity',
        'creation_date',
        'ticket_type',
        'creation_date',
        )



# -*- coding: utf-8 -*-
from django.db.models import Q

from rest_framework.generics import (ListCreateAPIView, ListAPIView,
    RetrieveUpdateDestroyAPIView, RetrieveUpdateAPIView
    )  # noqa
from rest_framework.pagination import PageNumberPagination
from rest_framework.response import Response

from simpletickets.api.permissions import (UserTicketPermission,
    StaffTicketPermission
    )  # noqa
from simpletickets.api.serializers import (UserTicketSerializer,
    StaffTicketSerializer
    )  # noqa
from simpletickets.models import Ticket


class Custom20Pagination(PageNumberPagination):
    '''
    A pagination class that paginates every 20 objects.
    '''
    page_size = 20
    page_size_query_param = 'page_size'
    max_page_size = 20

    def get_paginated_response(self, data):
        return Response({
                'links': {'next': self.get_next_link(),
                   'previous': self.get_previous_link()
                    },
                'count': self.page.paginator.count,
                'results': data
                }
            )


class MainMixin(object):
    '''
    The main mixin for all the views,
    where we manage the methods that are used more than once.
    '''
    def logged_user(self):
        '''
        Returns the user that is logged,
        '''
        return self.request.user


class UserTicketMixin(MainMixin):
    permission_classes = (UserTicketPermission, )
    serializer_class = UserTicketSerializer

    def get_queryset(self):
        return Ticket.objects.filter(user=self.logged_user())

    def perform_create(self, serializer):
        user = self.logged_user()
        serializer.save(user=user)


class UserTicketListCreate(UserTicketMixin, ListCreateAPIView):
    '''
    GET list of tickets in the database for the logged in user
    CREATE a ticket for the logged in user
    '''
    pass


class UserTicketUpdateDelete(UserTicketMixin, RetrieveUpdateDestroyAPIView):
    pass


class StaffTicketMixin(MainMixin):
    permission_classes = (StaffTicketPermission, )
    serializer_class = StaffTicketSerializer

    def get_queryset(self):
        return Ticket.objects.filter(
            Q(state=1) |
            Q(staff=self.request.user, state__lt=9)
            )

    def perform_create(self, serializer):
        user = self.logged_user()
        serializer.save(staff=user)


class StaffTicketList(StaffTicketMixin, ListAPIView):
    '''
    GET list of tickets in the database for the logged in staff member
    that is all the tickets assigned and all unassigned tickets
    '''
    pass


class StaffTicketUpdate(StaffTicketMixin, RetrieveUpdateAPIView):
    pass



# -*- coding: utf-8 -*-
from django.conf.urls import patterns, url

from rest_framework.urlpatterns import format_suffix_patterns

from simpletickets.api.views import UserTicketListCreate  # noqa


urlpatterns = patterns(
    url(r'^list/$', UserTicketListCreate.as_view(), name='ticketListCreate'),
    )

urlpatterns = format_suffix_patterns(urlpatterns)



# -*- coding: utf-8 -*-
from datetime import timedelta

from django.contrib.auth.decorators import login_required
from django.contrib.messages.views import SuccessMessageMixin
from django.core.urlresolvers import reverse_lazy
from django.db.models import Q
from django.utils.translation import ugettext_lazy as _

from django.views.generic import View
from django.views.generic.edit import CreateView, DeleteView, UpdateView
from django.views.generic.list import ListView

from .models import Ticket  # noqa
from .forms import TicketFormUser, TicketFormStaff
from .helpers import monitor, monitorfile
from .settings import (BASE_TEMPLATE, ST_FL_MNTR_OWNER, ST_FL_MNTR_STAFF,
    ST_SETT_NUMBERS_STAFF, ST_SETT_NUMBERS_OWNER, ST_SETT_TIMES_STAFF,
    ST_SETT_TIMES_OWNER, ST_SETT_MAIN_TASKBAR
    )


# MIXINS
class ContextMixin(SuccessMessageMixin, View):
    def get_context_data(self, **kwargs):
        context = super(ContextMixin, self).get_context_data(**kwargs)
        context['title'] = self.title
        context['base_template'] = BASE_TEMPLATE

        is_staff = self.request.user.is_staff
        context['ST_MNTR'] = is_staff and ST_FL_MNTR_STAFF or ST_FL_MNTR_OWNER
        stt_numb = is_staff and ST_SETT_NUMBERS_STAFF or ST_SETT_NUMBERS_OWNER
        stt_times = is_staff and ST_SETT_TIMES_STAFF or ST_SETT_TIMES_OWNER

        context['ST_SETT_MAIN_TASKBAR'] = ST_SETT_MAIN_TASKBAR

        if stt_numb:
            context['stt_numb'] = stt_numb
            n_solved = Ticket.objects.n_solved(self.request.user)
            n_total = Ticket.objects.n_total(self.request.user)
            if n_solved and n_total:
                context['porc_solved'] = n_solved * 100 / n_total
                context['porc_pending'] = 100 - context['porc_solved']
            elif n_total:
                context['porc_solved'] = 0
                context['porc_pending'] = 100
            else:
                context['porc_solved'] = 100
                context['porc_pending'] = 0
        if stt_times:
            context['statistic_times'] = stt_times
            all_tickets = Ticket.objects.all()
            if all_tickets.filter(state__gt=7):
                context['fastest'] = all_tickets.filter(state__gt=7
                    ).order_by('resolution_delta'
                    )[0].humanized_delta()
                if n_solved:
                    context['media'] = timedelta(
                        seconds=sum(
                            [t.resolution_delta for t in all_tickets.filter(
                                    state__gt=7)]) / n_solved
                        )
                else:
                    context['media'] = 'N/A'

        return context


class Login_required_mixin(View):
    @classmethod
    def as_view(self, **kwargs):
        return login_required(
            super(Login_required_mixin, self).as_view(**kwargs)
            )


class TicketMixin(object):
    def get_queryset(self):
        if self.request.user.is_staff:
            return Ticket.objects.filter(
                Q(state=1) |
                Q(staff=self.request.user, state__lt=9)
                )
        return Ticket.objects.filter(user=self.request.user)

    def get_object(self):
        return self.get_queryset().get(id=self.kwargs['ST_id'])
# END MIXINS


class TicketCreate(ContextMixin, Login_required_mixin, CreateView):
    title = _('Edit ticket')
    model = Ticket
    fields = ['ticket_type', 'severity', 'description', 'attachment', ]
    success_message = _('Ticket was successfully created')
    error_message = _('Please check the failures bellow')
    success_url = reverse_lazy('ticketList')

    def form_valid(self, form):
        form.instance.user = self.request.user
        return super(TicketCreate, self).form_valid(form)


class TicketDelete(ContextMixin, Login_required_mixin, TicketMixin,
        DeleteView):
    title = _('Delete ticket')
    model = Ticket
    success_url = reverse_lazy('home')
    success_message = _('Ticket was successfully deleted')
    success_url = reverse_lazy('ticketList')


class TicketUpdate(ContextMixin, Login_required_mixin, TicketMixin,
        UpdateView):
    title = _('Edit ticket')
    model = Ticket
    success_url = reverse_lazy('home')
    success_message = _('Ticket was successfully updated')
    success_url = reverse_lazy('ticketList')

    def getHeader(self, date, user):
        header_msg = _('{date} [user: {user}] ').format(date=date, user=user)
        return header_msg

    def get_form_class(self):
        if self.request.user.is_staff:
            return TicketFormStaff
        return TicketFormUser

    def form_valid(self, form):
        ticket = form.instance
        header_msg = self.getHeader(
            ticket.creation_date,
            self.request.user.username
            )
        if not ticket.staff and self.request.user.is_staff:
            ticket.staff = self.request.user
        if not self.request.user.is_staff and ticket.state == 8:
            ticket.state = 2
            ticket.resolution_date = None
            ticket.resolution_delta = None

        monitor(monitorfile(ticket), header_msg)
        return super(TicketUpdate, self).form_valid(form)


class TicketList(ContextMixin, Login_required_mixin, TicketMixin, ListView):
    model = Ticket
    title = _('Ticket list')



# -*- coding: utf-8 -*-
import os
from datetime import timedelta

from django.conf import settings
from django.utils.translation import ugettext as _

BASE_TEMPLATE = getattr(settings, 'BASE_TEMPLATE', 'index.html')

ST_REST_API = getattr(settings, 'ST_REST_API', True)

API_BASE_URL = getattr(settings, 'API_BASE_URL', 'api')

MONITOR_FILES_DIR = 'monitors'
ATTACHMENTS_DIR = 'tickets'

ST_ATTACHMENTS = os.path.join(settings.MEDIA_ROOT, ATTACHMENTS_DIR)

ST_ATTACH_URL = '{media_url}/{attachments_dir}/{monitor_files_dir}/'.format(
    media_url=settings.MEDIA_URL,
    attachments_dir=ATTACHMENTS_DIR,
    monitor_files_dir=MONITOR_FILES_DIR,
    )

ST_DELTA_CLOSE = getattr(settings, 'ST_DELTA_CLOSE', timedelta(hours=6))

ST_TCKT_TYPE = getattr(
    settings,
    'ST_TCKT_TYPE',
    (
        (1, _(u'Inform about an error')),
        (2, _(u'Problem')),
        (8, _(u'Propose a sugestion')),
        (9, _(u'Others')),
        )
    )

ST_TCKT_SEVERITY = getattr(
    settings,
    'ST_TCKT_SEVERITY',
    (
        (1, _(u'Low')),
        (2, _(u'Normal')),
        (5, _(u'important')),
        (8, _(u'very important')),
        (9, _(u'Critical')),
        )
    )

ST_TCKT_STATE = getattr(
    settings,
    'ST_TCKT_STATE',
    (
        (1, _(u'new')),
        (2, _(u'assigned')),
        (5, _(u'in progress')),
        (8, _(u'solved')),
        (9, _(u'closed')),
        )
    )

ST_FL_MNTR_STAFF = getattr(settings, 'ST_FL_MNTR_STAFF', True)
ST_FL_MNTR_OWNER = getattr(settings, 'ST_FL_MNTR_OWNER', False)

ST_SETT_MAIN_TASKBAR = getattr(
    settings, 'ST_SETT_MAIN_TASKBAR', True
    )

ST_SETT_TIMES_STAFF = getattr(
    settings, 'ST_SETT_TIMES_STAFF', True
    )
ST_SETT_NUMBERS_STAFF = getattr(
    settings, 'ST_SETT_NUMBERS_STAFF', True
    )

ST_SETT_TIMES_OWNER = getattr(
    settings, 'ST_SETT_TIMES_OWNER', True
    )
ST_SETT_NUMBERS_OWNER = getattr(
    settings, 'ST_SETT_NUMBERS_OWNER', True
    )



# -*- coding: utf-8 -*-
import os
from setuptools import setup

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='simpletickets',
    version='0.1',
    packages=['simpletickets'],
    include_package_data=True,
    license='BSD License',
    description='A simple Django app to create a ticketting system between '
            'users and staff.',
    long_description=README,
    url='https://github.com/monobot/simpletickets',
    download_url='https://github.com/monobot/simpletickets',
    author='Héctor Alvarez (monobot)',
    author_email='monobot.soft@gmail.com',
    keywords=['django', 'tickets'],
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        # Replace these appropriately if you are stuck on Python 2.
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
